Task: FVQA
===========
Description: The FVQA, a VQA dataset which requires, and supports, much deeper reasoning. We extend a conventional visual question answering dataset, which contains image-question-answer triplets, through additional image-question-answer-supporting fact tuples. The supporting fact is represented as a structural triplet, such as <Cat,CapableOf,ClimbingTrees>.  

Link: https://arxiv.org/abs/1606.05433

Tags: #FVQA, #All, #Visual

